summaryrefslogtreecommitdiffstats
path: root/examples/buttongroups/buttongroups.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'examples/buttongroups/buttongroups.cpp')
-rw-r--r--examples/buttongroups/buttongroups.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/buttongroups/buttongroups.cpp b/examples/buttongroups/buttongroups.cpp
index 2ec343d8..2ae71486 100644
--- a/examples/buttongroups/buttongroups.cpp
+++ b/examples/buttongroups/buttongroups.cpp
@@ -75,8 +75,8 @@ ButtonsGroups::ButtonsGroups( TQWidget *parent, const char *name )
// insert a checkbox...
state = new TQCheckBox( "E&nable Radiobuttons", bgrp3 );
state->setChecked( TRUE );
- // ...and connect its SIGNAL clicked() with the SLOT slotChangeGrp3State()
- connect( state, SIGNAL( clicked() ), this, SLOT( slotChangeGrp3State() ) );
+ // ...and connect its TQ_SIGNAL clicked() with the TQ_SLOT slotChangeGrp3State()
+ connect( state, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotChangeGrp3State() ) );
// ------------ fourth group
@@ -107,7 +107,7 @@ ButtonsGroups::ButtonsGroups( TQWidget *parent, const char *name )
}
/*
- * SLOT slotChangeGrp3State()
+ * TQ_SLOT slotChangeGrp3State()
*
* enables/disables the radiobuttons of the third buttongroup
*/